Terminal S
==========

[![](https://img.shields.io/pypi/v/terminal-s.svg)](https://pypi.org/project/terminal-s/)


A super simple serial terminal with [about 100 lines of Python code](terminal_s/terminal.py)

![](https://user-images.githubusercontent.com/948283/82290238-050e5600-99d9-11ea-9b36-50fb12471e95.png)


## Features

+ auto-detect serial port
+ list available ports to choose

## Install
```
pip install terminal-s
```

## Run
```
terminal-s
```

On windows, you can also type <kbd>Win</kbd> + <kbd>r</kbd> and enter `terminal-s` to launch it.

## Package
```
pip install pyinstaller
pyinstaller terminal-s.spec
```
